# Notes on Inverse Problems
### Python scripts and notebooks about (sparse) inverse problems, regularisation and optimisation

Up to now this project is essentially for me to become fluent in Python, and to produce teaching material under the form of notebooks:

I. Sparse Regularisation with the L1 norm (LASSO)
  1. [The regularization path](https://nbviewer.jupyter.org/github/Guillaume-Garrigos/invprob/blob/master/notebook/lasso_1-regularisation_path.ipynb)
  2. [Noise and parameter selection](https://nbviewer.jupyter.org/github/Guillaume-Garrigos/invprob/blob/master/notebook/lasso_2-noise_parameter_selection.ipynb)
